        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 29 <br>1,3,5,8,9,10,12,17,18,21,22,23,24,25,28,29,31,32,33,34,35,36,38,40,41,42,43,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260617 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 22 <strong>control</strong><br>0,2,4,6,7,11,13,14,15,16,19,20,26,27,30,37,39,44,45,46,47,48';}
}
